@@ -246,8 +246,18 @@ class BackupJob {
         $sourcePath = $metadata['source_path'];
         $user = $data['user'];
 
+        // Add .zip extension to localPath if not present
+        if (substr($localPath, -4) !== '.zip') {
+            $actualPath = $localPath . '.zip';
+            // Update database with actual path including .zip extension
+            $stmt = $this->db->prepare("UPDATE backup_history SET local_path = ? WHERE id = ?");
+            $stmt->execute([$actualPath, $data['id']]);
+        } else {
+            $actualPath = $localPath;
+        }
+
         // Create archive directly to local storage (use zip for better compatibility)
-        $this->createUserfilesArchiveZip($sourcePath, $localPath, $user);
+        $this->createUserfilesArchiveZip($sourcePath, $actualPath, $user);
     }
     
     private function createDatabaseBackup($data, $localPath) {
@@ -349,10 +359,10 @@ class BackupJob {
         if (!is_dir($sourcePath)) {
             throw new Exception("Userfiles directory not found: $sourcePath");
         }
-        
+
         $userDir = dirname($sourcePath);
         $userName = basename($userDir);
-        
+
         // Create zip archive
         $command = "cd " . escapeshellarg(dirname($userDir)) . " && zip -r " . escapeshellarg($tempFile) . " " . escapeshellarg($userName . "/userfiles") . " 2>&1";
 
@@ -361,11 +371,11 @@ class BackupJob {
         if ($returnCode !== 0) {
             throw new Exception("Failed to create userfiles archive: " . implode("\n", $output));
         }
-        
+
         if (!file_exists($tempFile) || filesize($tempFile) === 0) {
             throw new Exception("Userfiles archive file is empty or doesn't exist");
         }
-        
+
     }
     
     private function createDatabaseDump($database, $tempFile) {
